Learn R Programming

crn (version 1.0)

crn-package: Climate Reference Network datatools

Description

The crn package provides the core functions required to download and format data from the Climate Reference Network. Both daily and hourly data are downloaded from the ftp, a consoliated file of all stations is created, station metadata is extracted. In addition functions for selecting individual variables and creating R friendly datasets for them is provided.

Arguments

basic operations

The package provides the basic functions to download and organize CRN data into R friendly datastructures. The first function that should be used is downloadCRN, That function downloads either daily or hourly data depending on the variables you pass it. Next, collateDaily and collateHourly should be run. Finally, writeDataset is used to create files with individual variables in them.

Details

ll{ Package: crn Type: Package Version: 1.0 License: GPL (>=2) LazyLoad: yes LazyData: FALSE }

References

ftp://ftp.ncdc.noaa.gov/pub/data/uscrn/ ftp://ftp.ncdc.noaa.gov/pub/data/uscrn/products/

Examples

Run this code
downloadCRN()
   collateDaily()
   collateHourly()

Run the code above in your browser using DataLab